@@ -13,6 +13,7 @@ use crate::geom::{Angle, bbox_from_points};
 use crate::key::Key;
 use crate::config::Config;
 use crate::ui::Flags;
+use crate::serialize;
 
 #[derive(Copy,Clone,Debug, PartialEq, Eq)]
 /// Describes the possible states of the undo_queue and a pointer that moves
@@ -328,7 +329,7 @@ impl Pizarra {
             current_shape: None,
 
             selected_tool: SelectedTool::Shape(ShapeTool::Path),
-            bgcolor: Color::black(),
+            bgcolor: config.background_color,
             stroke: config.thickness,
             selected_color: config.stroke_color,
             erase_radius: config.erase_radius,
@@ -400,7 +401,7 @@ impl Pizarra {
     /// returns only the draw commands needed to paint the current shape on the
     /// screen.
     pub fn draw_commands_for_current_shape(&self) -> Option<Vec<DrawCommand>> {
-        self.current_shape.as_ref().map(|s| s.draw_commands())
+        self.current_shape.as_ref().map(|s| s.draw_commands(self.transform, self.config.point_snap_radius))
     }
 
     /// Notify the application that the screen size has changed
@@ -731,6 +732,15 @@ impl Pizarra {
 
         Ok(())
     }
+
+    pub fn to_svg(&self) -> String {
+        let settings = serialize::Settings {
+            export_padding: self.config.export_padding,
+            bgcolor: self.bgcolor,
+        };
+
+        self.storage.to_svg(settings)
+    }
 }
 
 #[cfg(test)]
@@ -738,7 +748,7 @@ mod tests {
     use super::*;
     use crate::{
         draw_commands::DrawCommand, app::SelectedTool,
-        shape::path::{PathCommand, CubicBezierCurve},
+        path_command::{PathCommand, CubicBezierCurve},
     };
     use PathCommand::*;
 
@@ -757,7 +767,8 @@ mod tests {
         let commands = app.draw_commands_for_screen();
 
         assert_eq!(commands[0], DrawCommand::Path {
-            color: Default::default(),
+            color: Some(Default::default()),
+            fill: None,
             commands: vec![
                 MoveTo(Vec2DWorld { x: -40.0, y: -30.0 }),
                 CurveTo(CubicBezierCurve {
@@ -787,7 +798,8 @@ mod tests {
         let commands = app.draw_commands_for_screen();
 
         assert_eq!(commands[0], DrawCommand::Path {
-            color: Default::default(),
+            color: Some(Default::default()),
+            fill: None,
             commands: vec![
                 MoveTo(Vec2DWorld { x: -20.0, y: -15.0 }),
                 CurveTo(CubicBezierCurve {
@@ -1014,7 +1026,8 @@ mod tests {
         assert_eq!(commands.len(), 1);
 
         assert_eq!(commands[0], DrawCommand::Path {
-            color: Default::default(),
+            color: Some(Default::default()),
+            fill: None,
             thickness: Config::default().thickness,
             commands: vec![
                 MoveTo(Vec2DWorld { x: -30.0, y: -20.0 }),
